@@ -33,46 +33,49 @@ class ExecutionReport(BaseModel):
     testMode: str
     status: str = "FAILURE"
     customOutput: Optional[CustomModelOutput]
-    numberOfTimeValuesSuccessfullyParsed: StrictInt = 0
-    numberOfTimeValuesDeletionSuccessfullyParsed: StrictInt = 0
-    numberOfBatchValuesSuccessfullyParsed: StrictInt = 0
+    numberOfTimeValuesCreatedOrUpdated: StrictInt = 0
+    numberOfTimeValuesDeleted: StrictInt = 0
+    numberOfBatchValuesCreatedOrUpdated: StrictInt = 0
+    numberOfBatchTagsCreatedOrUpdated: StrictInt = 0
     numberOfBatchCreatedOrUpdated: StrictInt = 0
     numberOfEventCreatedOrUpdated: StrictInt = 0
-    numberOfEventValuesSuccessfullyParsed: StrictInt = 0
-    numberOfEventTagsSuccessfullyParsed: StrictInt = 0
-    numberOfBatchRelationsSuccessfullyParsed: StrictInt = 0
-    numberOfParsingErrors: StrictInt = 0
-    numberOfInvalidValues: StrictInt = 0
-    numberOfTimeVectorValuesSuccessfullyParsed: StrictInt = 0
-    numberOfBatchVectorValuesSuccessfullyParsed: StrictInt = 0
+    numberOfEventValuesCreatedOrUpdated: StrictInt = 0
+    numberOfEventTagsCreatedOrUpdated: StrictInt = 0
+    numberOfBatchRelationsCreatedOrUpdated: StrictInt = 0
+    numberOfErrors: StrictInt = 0
+    numberOfTimeVectorValuesCreatedOrUpdated: StrictInt = 0
+    numberOfBatchVectorValuesCreatedOrUpdated: StrictInt = 0
+    numberOfFilesUploaded: StrictInt = 0
 
     def update(
         self,
-        time_values_parsed: StrictInt = 0,
+        time_values_updated: StrictInt = 0,
         time_values_deleted: StrictInt = 0,
-        batch_values_parsed: StrictInt = 0,
+        batch_values_updated: StrictInt = 0,
+        batch_tags_updated: StrictInt = 0,
         batch_created_updated: StrictInt = 0,
         events_created_updated: StrictInt = 0,
-        event_values_parsed: StrictInt = 0,
-        event_tags_parsed: StrictInt = 0,
-        batch_relations_parsed: StrictInt = 0,
-        parsing_errors: StrictInt = 0,
-        invalid_values: StrictInt = 0,
-        time_vector_values_parsed: StrictInt = 0,
-        batch_vector_values_parsed: StrictInt = 0,
+        event_values_updated: StrictInt = 0,
+        event_tags_updated: StrictInt = 0,
+        batch_relations_updated: StrictInt = 0,
+        errors: StrictInt = 0,
+        time_vector_values_updated: StrictInt = 0,
+        batch_vector_values_updated: StrictInt = 0,
+        files_uploaded: StrictInt = 0,
     ):
-        self.numberOfTimeValuesSuccessfullyParsed += time_values_parsed
-        self.numberOfTimeValuesDeletionSuccessfullyParsed += time_values_deleted
-        self.numberOfBatchValuesSuccessfullyParsed += batch_values_parsed
+        self.numberOfTimeValuesCreatedOrUpdated += time_values_updated
+        self.numberOfTimeValuesDeleted += time_values_deleted
+        self.numberOfBatchValuesCreatedOrUpdated += batch_values_updated
+        self.numberOfBatchTagsCreatedOrUpdated += batch_tags_updated
         self.numberOfBatchCreatedOrUpdated += batch_created_updated
         self.numberOfEventCreatedOrUpdated += events_created_updated
-        self.numberOfEventValuesSuccessfullyParsed += event_values_parsed
-        self.numberOfEventTagsSuccessfullyParsed += event_tags_parsed
-        self.numberOfBatchRelationsSuccessfullyParsed += batch_relations_parsed
-        self.numberOfParsingErrors += parsing_errors
-        self.numberOfInvalidValues += invalid_values
-        self.numberOfTimeVectorValuesSuccessfullyParsed += time_vector_values_parsed
-        self.numberOfBatchVectorValuesSuccessfullyParsed += batch_vector_values_parsed
+        self.numberOfEventValuesCreatedOrUpdated += event_values_updated
+        self.numberOfEventTagsCreatedOrUpdated += event_tags_updated
+        self.numberOfBatchRelationsCreatedOrUpdated += batch_relations_updated
+        self.numberOfErrors += errors
+        self.numberOfTimeVectorValuesCreatedOrUpdated += time_vector_values_updated
+        self.numberOfBatchVectorValuesCreatedOrUpdated += batch_vector_values_updated
+        self.numberOfFilesUploaded += files_uploaded
 
     def set_as_default_report(self):
         set_default_execution_report(self)
@@ -124,7 +127,18 @@ class FileReceptionTrigger(BaseModel):
         return value
 
 
-Trigger = Union[CronTrigger, FileReceptionTrigger]
+# Manual only trigger
+class ManualOnlyTrigger(BaseModel):
+    type: StrictStr
+
+    @validator("type")
+    def check_type(cls, value):
+        if value != "manual-only":
+            raise ValueError("Trigger type should be 'manual-only'")
+        return value
+
+
+Trigger = Union[CronTrigger, FileReceptionTrigger, ManualOnlyTrigger]
 
 
 # Model inputs & outputs
@@ -641,8 +655,8 @@ class StoredTimeVectorDataParameter(BaseModel):
 
     @validator("type")
     def validate_type(cls, value):
-        if value != "STORED_TIME_VECTOR_DATA":
-            raise ValueError("'type' should be 'STORED_TIME_VECTOR_DATA'")
+        if value != "STORED_CONTINUOUS_VECTOR_DATA":
+            raise ValueError("'type' should be 'STORED_CONTINUOUS_VECTOR_DATA'")
         return value
 
     @property
