@@ -60,8 +60,16 @@ class FileOutput:
         return cls(file_name=file_name, content=bio)
 
     def send_to_oianalytics(
-        self, api_credentials: Optional[api.OIAnalyticsAPICredentials] = None
+        self,
+        api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
+        execution_report: Optional[ExecutionReport] = None,
     ):
+        # get execution report
+        if execution_report is None:
+            execution_report = get_default_execution_report()
+        # update execution report
+        execution_report.update(files_uploaded=1)
+
         return api.endpoints.files.upload_file(
             file_content=self.content,
             file_name=self.file_name,
@@ -117,7 +125,7 @@ class TimeValuesOutput:
     def send_to_oianalytics(
         self,
         api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
-        summary: Optional[ExecutionReport] = None,
+        execution_report: Optional[ExecutionReport] = None,
     ):
         # send data
         response = api.insert_time_values(
@@ -127,14 +135,13 @@ class TimeValuesOutput:
             timestamp_index_name=self.timestamp_index_name,
             api_credentials=api_credentials,
         )
-        # get summary
-        if summary is None:
-            summary = get_default_execution_report()
-        # update summary
-        summary.update(
-            time_values_parsed=response.get("numberOfValuesSuccessfullyInserted", 0),
-            invalid_values=response.get("numberOfValuesRejected", 0),
-            parsing_errors=len(response.get("errors", [])),
+        # get execution report
+        if execution_report is None:
+            execution_report = get_default_execution_report()
+        # update execution report
+        execution_report.update(
+            time_values_updated=response.get("numberOfValuesSuccessfullyInserted", 0),
+            errors=len(response.get("errors", [])),
         )
         return response
 
@@ -144,6 +151,7 @@ class VectorTimeValuesOutput:
         self,
         data: List[pd.DataFrame],
         data_reference: List[str],
+        rename_data: bool = True,
         values_units: Optional[dict[str, str]] = None,
         index_units: Optional[dict[str, str]] = None,
         use_external_reference: bool = False,
@@ -151,9 +159,22 @@ class VectorTimeValuesOutput:
     ):
         self.output_type = "time_vector_values"
 
-        self.data = data
+        if rename_data is True:
+            model_exec = get_default_model_execution()
+            if model_exec is None:
+                raise ValueError(
+                    "Data can't be renamed without a current model_exec set globally"
+                )
+
+            output_dict = model_exec.get_data_output_dict(
+                data_type="time", values_type="vector", mode="reference"
+            )
+            data_reference = [
+                output_dict[source_code_name] for source_code_name in data_reference
+            ]
 
         self.data_reference = data_reference
+        self.data = data
 
         # Specify values units
         if values_units is None:
@@ -162,7 +183,7 @@ class VectorTimeValuesOutput:
                 self.values_units = {
                     output_data.reference: output_data.valueUnit.label
                     for output_data in model_exec.get_data_output_dict(
-                        data_type="any", values_type="vector", mode="object"
+                        data_type="time", values_type="vector", mode="object"
                     ).values()
                     if output_data.reference in data_reference
                 }
@@ -176,7 +197,7 @@ class VectorTimeValuesOutput:
                 self.index_units = {
                     output_data.reference: output_data.indexUnit.label
                     for output_data in model_exec.get_data_output_dict(
-                        data_type="any", values_type="vector", mode="object"
+                        data_type="time", values_type="vector", mode="object"
                     ).values()
                     if output_data.reference in data_reference
                 }
@@ -190,7 +211,7 @@ class VectorTimeValuesOutput:
     def send_to_oianalytics(
         self,
         api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
-        summary: Optional[ExecutionReport] = None,
+        execution_report: Optional[ExecutionReport] = None,
     ):
         # send data
         response = api.insert_vector_time_values(
@@ -202,15 +223,15 @@ class VectorTimeValuesOutput:
             timestamp_index_name=self.timestamp_index_name,
             api_credentials=api_credentials,
         )
-        # update summary
-        if summary is None:
-            summary = get_default_execution_report()
-        summary.update(
-            time_vector_values_parsed=response.get(
+        # get execution report
+        if execution_report is None:
+            execution_report = get_default_execution_report()
+        # update execution report
+        execution_report.update(
+            errors=len(response.get("errors", [])),
+            time_vector_values_updated=response.get(
                 "numberOfValuesSuccessfullyInserted", 0
             ),
-            invalid_values=response.get("numberOfValuesRejected", 0),
-            parsing_errors=len(response.get("errors", [])),
         )
         return response
 
@@ -262,11 +283,11 @@ class BatchValuesOutput:
     def send_to_oianalytics(
         self,
         api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
-        summary: Optional[ExecutionReport] = None,
+        execution_report: Optional[ExecutionReport] = None,
     ):
-        # get summary
-        if summary is None:
-            summary = get_default_execution_report()
+        # get execution report
+        if execution_report is None:
+            execution_report = get_default_execution_report()
         try:
             # send data
             response = api.update_batch_values(
@@ -276,10 +297,12 @@ class BatchValuesOutput:
                 batch_id_index_name=self.batch_id_index_name,
                 api_credentials=api_credentials,
             )
-            summary.update(batch_values_parsed=self.data.count().sum())
+
+            # update execution report
+            execution_report.update(batch_values_updated=int(self.data.count().sum()))
             return response
-        except:
-            summary.update(parsing_errors=1)
+        except Exception:
+            execution_report.update(errors=1)
 
 
 class VectorBatchValuesOutput:
@@ -290,11 +313,25 @@ class VectorBatchValuesOutput:
         values_units: Optional[dict[str, str]] = None,
         index_units: Optional[dict[str, str]] = None,
         batch_id_index_name: str = "batch_id",
+        rename_data: bool = True,
     ):
         self.output_type = "batch_vector_values"
 
-        self.data_reference = data_reference
+        if rename_data is True:
+            model_exec = get_default_model_execution()
+            if model_exec is None:
+                raise ValueError(
+                    "Data can't be renamed without a current model_exec set globally"
+                )
 
+            output_dict = model_exec.get_data_output_dict(
+                data_type="batch", values_type="vector", mode="reference"
+            )
+            data_reference = [
+                output_dict[source_code_name] for source_code_name in data_reference
+            ]
+
+        self.data_reference = data_reference
         self.data = data
 
         # Specify units
@@ -320,7 +357,7 @@ class VectorBatchValuesOutput:
                     for output_data in model_exec.get_data_output_dict(
                         data_type="batch", values_type="vector", mode="object"
                     ).values()
-                    if index_units.reference in data_reference
+                    if output_data.reference in data_reference
                 }
         else:
             self.index_units = index_units
@@ -330,29 +367,26 @@ class VectorBatchValuesOutput:
     def send_to_oianalytics(
         self,
         api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
-        summary: Optional[ExecutionReport] = None,
+        execution_report: Optional[ExecutionReport] = None,
     ):
         # send data
         response = api.update_vector_batch_values(
             data=self.data,
             data_reference=self.data_reference,
             index_units=self.index_units,
-            unit_ids=self.values_units,
+            values_units=self.values_units,
             batch_id_index_name=self.batch_id_index_name,
             api_credentials=api_credentials,
         )
-        # update summary
-        if summary is None:
-            summary = get_default_execution_report()
-        summary.update(
-            batch_vector_values_parsed=(
-                summary.numberOfBatchVectorValuesSuccessfullyParsed
-                + response.get("numberOfValuesSuccessfullyInserted", 0)
+        # get execution report
+        if execution_report is None:
+            execution_report = get_default_execution_report()
+        # update execution report
+        execution_report.update(
+            errors=len(response.get("errors", [])),
+            batch_vector_values_updated=response.get(
+                "numberOfValuesSuccessfullyInserted", 0
             ),
-            invalid_values=summary.numberOfInvalidValues
-            + response.get("numberOfValuesRejected", 0),
-            parsing_errors=summary.numberOfParsingErrors
-            + len(response.get("errors", [])),
         )
         return response
 
@@ -388,15 +422,28 @@ class BatchFeaturesOutput:
         self.batch_id_index_name = batch_id_index_name
 
     def send_to_oianalytics(
-        self, api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
+        self,
+        api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
+        execution_report: Optional[ExecutionReport] = None,
     ):
+        # update execution report
+        if execution_report is None:
+            execution_report = get_default_execution_report()
+
         # send data
-        return api.update_batch_feature_values(
-            batch_type_id=self.batch_type_id,
-            data=self.data,
-            batch_id_index_name=self.batch_id_index_name,
-            api_credentials=api_credentials,
-        )
+        try:
+            response = api.update_batch_feature_values(
+                batch_type_id=self.batch_type_id,
+                data=self.data,
+                batch_id_index_name=self.batch_id_index_name,
+                api_credentials=api_credentials,
+            )
+
+            # update execution report
+            execution_report.update(batch_tags_updated=int(self.data.count().sum()))
+            return response
+        except Exception:
+            execution_report.update(errors=1)
 
 
 class Delay:
@@ -405,8 +452,14 @@ class Delay:
         self.duration = duration
 
     def send_to_oianalytics(
-        self, api_credentials: Optional[api.OIAnalyticsAPICredentials] = None
+        self,
+        api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
+        execution_report: Optional[ExecutionReport] = None,
     ):
+        # update execution report
+        if execution_report is None:
+            execution_report = get_default_execution_report()
+
         time.sleep(self.duration)
 
 
@@ -415,7 +468,11 @@ class CustomTextOutput:
         self.type = "text"
         self.content = content
 
-    def send_to_oianalytics(self, execution_report: Optional[ExecutionReport] = None):
+    def send_to_oianalytics(
+        self,
+        api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
+        execution_report: Optional[ExecutionReport] = None,
+    ):
         # Get the default execution report if not provided
         if execution_report is None:
             execution_report = get_default_execution_report()
@@ -431,7 +488,11 @@ class CustomJsonOutput:
         self.type = "json"
         self.content = content
 
-    def send_to_oianalytics(self, execution_report: Optional[ExecutionReport] = None):
+    def send_to_oianalytics(
+        self,
+        api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
+        execution_report: Optional[ExecutionReport] = None,
+    ):
         # Get the default execution report if not provided
         if execution_report is None:
             execution_report = get_default_execution_report()
@@ -450,13 +511,24 @@ class OIModelOutputs:
     def add_output(
         self,
         output_object: Union[
-            FileOutput, TimeValuesOutput, Delay, CustomTextOutput, CustomJsonOutput
+            FileOutput,
+            TimeValuesOutput,
+            BatchValuesOutput,
+            VectorTimeValuesOutput,
+            VectorBatchValuesOutput,
+            Delay,
+            CustomTextOutput,
+            CustomJsonOutput,
         ],
     ):
         self.model_outputs.append(output_object)
 
     def send_to_oianalytics(
-        self, api_credentials: Optional[api.OIAnalyticsAPICredentials] = None
+        self,
+        api_credentials: Optional[api.OIAnalyticsAPICredentials] = None,
+        execution_report: Optional[ExecutionReport] = None,
     ):
         for model_output in self.model_outputs:
-            model_output.send_to_oianalytics(api_credentials=api_credentials)
+            model_output.send_to_oianalytics(
+                api_credentials=api_credentials, execution_report=execution_report
+            )
